@@ -619,6 +619,13 @@ def test_install_collection_from_disk_fail() -> None:
             runtime.prepare_environment(install_local=True)
 
 
+def test_prepare_environment_offline_role() -> None:
+    """Ensure that we can make use of offline roles."""
+    with remember_cwd("test/roles/acme.missing_deps"):
+        runtime = Runtime(isolated=True)
+        runtime.prepare_environment(install_local=True, offline=True)
+
+
 def test_runtime_run(runtime: Runtime) -> None:
     """Check if tee and non tee mode return same kind of results."""
     result1 = runtime.exec(["seq", "10"])
